@@ -1,5 +1,5 @@
 package HTML::TableTiler      ;
-$VERSION = 1.06               ;
+$VERSION = 1.07               ;
 use 5.005                     ;
 use Carp qw ( croak )         ;
 use HTML::PullParser 1.0      ;
@@ -164,6 +164,8 @@ __END__
 
 HTML::TableTiler - easily generates complex graphic styled HTML tables
 
+=head1 VERSION 1.07
+
 =head1 SYNOPSIS
 
 =over
@@ -758,9 +760,6 @@ I would like to have just a line of feedback from everybody who tries or actuall
 
 Domizio Demichelis, <dd@4pro.net>.
 
-=for html
-<img src="http://perl.4pro.net/bug?HTML::TableTiler" height="1" width="1" border="0">
-
 =head1 COPYRIGHT
 
 Copyright (c)2002 Domizio Demichelis. All Rights Reserved. This is free software; it may be used freely and redistributed for free providing this copyright header remains part of the software. You may not charge for the redistribution of this software. Selling this code without Domizio Demichelis' written permission is expressly forbidden.
